@@ -9,11 +9,10 @@ from pint.errors import DimensionalityError
 import numpy as np
 import tango
 from PyQt5 import QtCore
-from taurus import Attribute, Manager, Release
+from taurus import Attribute, Manager
 from taurus.core.tango.enums import DevState
 from taurus.core.taurusbasetypes import (
     TaurusEventType, TaurusSerializationMode)
-from taurus.external.qt import Qt
 from taurus.qt.qtgui.application import TaurusApplication
 from taurus.qt.qtgui.container import TaurusWidget
 from taurus.qt.qtgui.panel import TaurusDevicePanel
@@ -21,8 +20,6 @@ from taurus.qt.qtgui.panel import TaurusDevicePanel
 from .synopticwidget import SynopticWidget
 from .taurusregistry import Registry
 
-TAURUS_VERSION = Release.version_info[0]
-
 
 class TooltipUpdater(QtCore.QThread):
 
@@ -38,8 +35,8 @@ class TooltipUpdater(QtCore.QThread):
             attribute = Attribute(str(self.model) + "/State")
             if attribute:
                 value = attribute.read()
-                html = json.dumps('Value:&nbsp;' +
-                                  '<span class="value">%s</span>'
+                html = json.dumps('Value:&nbsp;'
+                                  + '<span class="value">%s</span>'
                                   % value.value)
             self.finished.emit(self.model, html)
         except tango.DevFailed as e:
@@ -92,20 +89,11 @@ class TaurusSynopticWidget(SynopticWidget, TaurusWidget):
         # self.tooltip_registry.start()
 
     def _hovered(self, sec, mods):
-        attr = self.registry.get_listener(str(mods))
+        self.registry.get_listener(str(mods))
 
     def getModel(self):
         return self._url
 
-    def closeEvent(self, event):
-        """
-        Clean things up when the widget is closed
-        """
-        self.registry.clear()
-        self.registry.stop()
-        self.registry.wait()
-        self.registry = None
-
     def run_plugin_command(self, plugin, cmd, args):
         try:
             plugins = __import__("plugins.%s" % plugin, globals(),
@@ -226,10 +214,8 @@ class TaurusSynopticWidget(SynopticWidget, TaurusWidget):
                 # spectrums/images break completely. I'm not sure
                 # we should even support those...
                 try:
-                    if TAURUS_VERSION == 4:
-                        fmt = "%" + evt_src.format_spec
-                        value = fmt % value    # taurus4 issue: values without format
-                    text = value
+                    fmt = "%" + evt_src.format_spec
+                    text = fmt % value
                 except AttributeError:
                     text = str(value)
                 except DimensionalityError:
@@ -365,9 +351,9 @@ class TaurusSynopticWidget(SynopticWidget, TaurusWidget):
         data = {"Class": "...", "State": "...", "Status": "..."}
         data.update(self._tooltip_data[device])
         html = json.dumps(
-            ('<div>Class:&nbsp;<span>{Class}</span></div>' +
-             '<div>State:&nbsp;<span class="{State}">{State}</span></div>' +
-             '<div>Status:&nbsp;<span>{Status}</span></div>').format(**data))
+            ('<div>Class:&nbsp;<span>{Class}</span></div>'
+             + '<div>State:&nbsp;<span class="{State}">{State}</span></div>'
+             + '<div>Status:&nbsp;<span>{Status}</span></div>').format(**data))
         self.js.evaluate('synoptic.setTooltipHTML("%s", %s)' %
                          (device, html))
 
